@@ -24,17 +24,16 @@ from signal import signal, SIGINT, SIGTERM
 
 
 try:
-    from lollypop.lastfm import LastFM
+    from lollypop.lastfm import LastFM, LibreFM
 except Exception as e:
     print(e)
     print("$ sudo pip3 install pylast")
     LastFM = None
 
-from lollypop.utils import set_proxy_from_gnome
+from lollypop.utils import set_proxy_from_gnome, install_youtube_dl
 from lollypop.application_actions import ApplicationActions
-from lollypop.utils import is_audio, is_pls
-from lollypop.define import Type, LOLLYPOP_DATA_PATH, ScanType
-from lollypop.window import Window
+from lollypop.utils import is_audio, is_pls, emit_signal
+from lollypop.define import Type, LOLLYPOP_DATA_PATH, ScanType, StorageType
 from lollypop.database import Database
 from lollypop.player import Player
 from lollypop.inhibitor import Inhibitor
@@ -49,7 +48,10 @@ from lollypop.database_genres import GenresDatabase
 from lollypop.database_tracks import TracksDatabase
 from lollypop.notification import NotificationManager
 from lollypop.playlists import Playlists
-from lollypop.objects import Album, Track
+from lollypop.objects_track import Track
+from lollypop.objects_album import Album
+from lollypop.objects_radio import Radio
+from lollypop.radios import Radios
 from lollypop.helper_task import TaskHelper
 from lollypop.helper_art import ArtHelper
 from lollypop.collectionscanner import CollectionScanner
@@ -63,16 +65,18 @@ class Application(Gtk.Application, ApplicationActions):
             - Create main window
     """
 
-    def __init__(self, version):
+    def __init__(self, version, data_dir):
         """
             Create application
             @param version as str
+            @param data_dir as str
         """
         Gtk.Application.__init__(
             self,
             application_id="org.gnome.Lollypop",
             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
         self.__version = version
+        self.__data_dir = data_dir
         self.set_property("register-session", True)
         signal(SIGINT, lambda a, b: self.quit())
         signal(SIGTERM, lambda a, b: self.quit())
@@ -102,14 +106,16 @@ class Application(Gtk.Application, ApplicationActions):
                     GLib.setenv("SSL_CERT_FILE", path, True)
                     break
         self.cursors = {}
-        self.notify = None
         self.scrobblers = []
         self.debug = False
         self.shown_sidebar_tooltip = False
         self.__window = None
         self.__fs_window = None
         self.__scanner_timeout_id = None
+        self.__spotify_timeout_id = None
         self.__scanner_uris = []
+        settings = Gio.Settings.new("org.gnome.desktop.interface")
+        self.animations = settings.get_value("enable-animations").get_boolean()
         GLib.set_application_name("Lollypop")
         GLib.set_prgname("lollypop")
         self.add_main_option("play-ids", b"a", GLib.OptionFlags.NONE,
@@ -180,14 +186,16 @@ class Application(Gtk.Application, ApplicationActions):
         self.artists = ArtistsDatabase()
         self.genres = GenresDatabase()
         self.tracks = TracksDatabase()
+        self.radios = Radios()
         self.player = Player()
         self.inhibitor = Inhibitor()
         self.scanner = CollectionScanner()
-        self.art = Art()
         self.notify = NotificationManager()
-        self.art.update_art_size()
         self.task_helper = TaskHelper()
         self.art_helper = ArtHelper()
+        self.art = Art()
+        self.art.update_art_size()
+        self.art.clean_old_artwork()
         self.spotify = SpotifyHelper()
         if not self.settings.get_value("disable-mpris"):
             from lollypop.mpris import MPRIS
@@ -200,24 +208,45 @@ class Application(Gtk.Application, ApplicationActions):
             dark = self.settings.get_value("dark-ui")
             settings.set_property("gtk-application-prefer-dark-theme", dark)
         ApplicationActions.__init__(self)
-        startup_one_ids = self.settings.get_value("startup-one-ids")
-        startup_two_ids = self.settings.get_value("startup-two-ids")
-        if startup_one_ids:
-            self.settings.set_value("state-one-ids", startup_one_ids)
-            self.settings.set_value("state-three-ids", GLib.Variant("ai", []))
-        if startup_two_ids:
-            self.settings.set_value("state-two-ids", startup_two_ids)
+        monitor = Gio.NetworkMonitor.get_default()
+        if monitor.get_network_available() and\
+                not monitor.get_network_metered() and\
+                self.settings.get_value("recent-youtube-dl"):
+            self.task_helper.run(install_youtube_dl)
+        self.start_spotify()
+
+    def start_spotify(self):
+        """
+            Start spotify timeout and start a new populate
+        """
+        if Type.SUGGESTIONS not in\
+                self.settings.get_value("shown-album-lists"):
+            return
+        if self.__spotify_timeout_id is None:
+            self.spotify.populate_db()
+            self.__spotify_timeout_id = GLib.timeout_add_seconds(
+                3600, self.spotify.populate_db)
+
+    def stop_spotify(self):
+        """
+            Stop spotify timeout and stop current populate
+        """
+        if self.__spotify_timeout_id is not None:
+            self.spotify.stop()
+            GLib.source_remove(self.__spotify_timeout_id)
+            self.__spotify_timeout_id = None
 
     def do_startup(self):
         """
             Init application
         """
         Gtk.Application.do_startup(self)
-
         if self.__window is None:
+            from lollypop.window import Window
             self.init()
             self.__window = Window()
             self.__window.connect("delete-event", self.__hide_on_delete)
+            self.__window.setup()
             self.__window.show()
             self.player.restore_state()
 
@@ -226,40 +255,21 @@ class Application(Gtk.Application, ApplicationActions):
             Quit Lollypop
             @param vacuum as bool
         """
+        self.__window.hide()
+        if self.spotify.is_running:
+            self.spotify.stop()
+            GLib.timeout_add(100, self.quit, vacuum)
+            return
         if self.settings.get_value("save-state"):
-            # Special case, we can't handle this earlier
-            if self.window.is_adaptive:
-                visible = self.window.container.stack.get_visible_child()
-                if visible == self.window.container.list_one:
-                    self.settings.set_value("state-one-ids",
-                                            GLib.Variant("ai", []))
-                    self.settings.set_value("state-two-ids",
-                                            GLib.Variant("ai", []))
-                elif visible == self.window.container.list_two:
-                    selected_ids = self.window.container.list_one.selected_ids
-                    self.settings.set_value("state-one-ids",
-                                            GLib.Variant("ai", selected_ids))
-                    self.settings.set_value("state-two-ids",
-                                            GLib.Variant("ai", []))
-        else:
-            self.settings.set_value("state-one-ids", GLib.Variant("ai", []))
-            self.settings.set_value("state-two-ids", GLib.Variant("ai", []))
+            self.__window.container.stack.save_history()
         # Then vacuum db
         if vacuum:
             self.__vacuum()
             self.art.clean_web()
-        self.__window.hide()
         for scrobbler in self.scrobblers:
             scrobbler.save()
         Gio.Application.quit(self)
 
-    def set_mini(self):
-        """
-            Set mini player on/off
-        """
-        if self.__window is not None:
-            self.__window.set_mini()
-
     def load_listenbrainz(self):
         """
             Load listenbrainz support if needed
@@ -285,7 +295,8 @@ class Application(Gtk.Application, ApplicationActions):
         if self.__fs_window is None:
             self.__window.hide()
             from lollypop.fullscreen import FullScreen
-            self.__fs_window = FullScreen(self)
+            self.__fs_window = FullScreen()
+            self.__fs_window.delayed_init()
             self.__fs_window.show()
             self.__fs_window.connect("destroy", on_destroy)
 
@@ -344,6 +355,14 @@ class Application(Gtk.Application, ApplicationActions):
         else:
             return self.__window
 
+    @property
+    def data_dir(self):
+        """
+            Get data dir
+            @return str
+        """
+        return self.__data_dir
+
     @property
     def gtk_application_prefer_dark_theme(self):
         """
@@ -352,6 +371,14 @@ class Application(Gtk.Application, ApplicationActions):
         """
         return self.__gtk_dark
 
+    @property
+    def version(self):
+        """
+            Get Lollypop version
+            @return srt
+        """
+        return self.__version
+
 #######################
 # PRIVATE             #
 #######################
@@ -363,13 +390,8 @@ class Application(Gtk.Application, ApplicationActions):
             return
 
         if self.player.current_track.id is None or\
-                self.player.current_track.mtime == 0:
+                self.player.current_track.storage_type & StorageType.EPHEMERAL:
             track_id = None
-        elif self.player.current_track.id == Type.RADIOS:
-            from lollypop.radios import Radios
-            radios = Radios()
-            track_id = radios.get_id(
-                self.player.current_track.radio_name)
         else:
             track_id = self.player.current_track.id
             # Save albums context
@@ -384,12 +406,10 @@ class Application(Gtk.Application, ApplicationActions):
         dump(self.player.queue,
              open(LOLLYPOP_DATA_PATH + "/queue.bin", "wb"))
         # Save current playlist
-        if self.player.current_track.id == Type.RADIOS:
+        if isinstance(self.player.current_track, Radio):
             playlist_ids = [Type.RADIOS]
-        elif not self.player.playlist_ids:
-            playlist_ids = []
         else:
-            playlist_ids = self.player.playlist_ids
+            playlist_ids = []
         dump(playlist_ids,
              open(LOLLYPOP_DATA_PATH + "/playlist_ids.bin", "wb"))
         if self.player.current_track.id is not None:
@@ -409,11 +429,14 @@ class Application(Gtk.Application, ApplicationActions):
                 self.scanner.stop()
                 GLib.idle_add(self.__vacuum)
                 return
-            self.tracks.del_non_persistent()
-            self.tracks.clean()
-            self.albums.clean()
-            self.artists.clean()
-            self.genres.clean()
+            SqlCursor.add(self.db)
+            self.tracks.del_non_persistent(False)
+            self.tracks.clean(False)
+            self.albums.clean(False)
+            self.artists.clean(False)
+            self.genres.clean(False)
+            SqlCursor.commit(self.db)
+            SqlCursor.remove(self.db)
 
             from lollypop.radios import Radios
             with SqlCursor(self.db) as sql:
@@ -456,8 +479,7 @@ class Application(Gtk.Application, ApplicationActions):
             # We are forced to enable scrobblers here if we want full debug
             if not self.scrobblers:
                 if LastFM is not None:
-                    self.scrobblers = [LastFM("lastfm"),
-                                       LastFM("librefm")]
+                    self.scrobblers = [LastFM(), LibreFM()]
                 self.load_listenbrainz()
             if options.contains("set-rating"):
                 value = options.lookup_value("set-rating").get_string()
@@ -530,8 +552,8 @@ class Application(Gtk.Application, ApplicationActions):
             elif self.__window is not None:
                 if not self.__window.is_visible():
                     self.__window.present()
-                    self.player.emit("status-changed")
-                    self.player.emit("current-changed")
+                    emit_signal(self.player, "status-changed")
+                    emit_signal(self.player, "current-changed")
             Gdk.notify_startup_complete()
         except Exception as e:
             Logger.error("Application::__on_command_line(): %s", e)
@@ -547,7 +569,7 @@ class Application(Gtk.Application, ApplicationActions):
         def scanner_update():
             self.__scanner_timeout_id = None
             self.player.play_uris(self.__scanner_uris)
-            self.scanner.update(ScanType.EPHEMERAL, self.__scanner_uris)
+            self.scanner.update(ScanType.EXTERNAL, self.__scanner_uris)
             self.__scanner_uris = []
 
         if self.__scanner_timeout_id is not None:
@@ -575,8 +597,7 @@ class Application(Gtk.Application, ApplicationActions):
         # Quit if background mode is on but player is off
         if not self.settings.get_value("background-mode") or\
                 not self.player.is_playing:
-            self.player.pause()
-            GLib.timeout_add(500, self.quit, True)
+            GLib.idle_add(self.quit, True)
         return widget.hide_on_delete()
 
     def __on_activate(self, application):
