@@ -12,9 +12,12 @@
 
 from gi.repository import GLib, GdkPixbuf, Gio
 
+from hashlib import md5
+
 from lollypop.define import ArtBehaviour, ArtSize
+from lollypop.define import CACHE_PATH
 from lollypop.logger import Logger
-from lollypop.utils import escape
+from lollypop.utils import escape, emit_signal
 
 
 class ArtistArt:
@@ -81,7 +84,7 @@ class ArtistArt:
             pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
             stream.close()
             pixbuf.savev(filepath, "jpeg", ["quality"], ["100"])
-        GLib.idle_add(self.emit, "artist-artwork-changed", artist)
+        emit_signal(self, "artist-artwork-changed", artist)
 
     def get_artist_artwork(self, artist, width, height, scale_factor,
                            behaviour=ArtBehaviour.CACHE):
@@ -111,7 +114,7 @@ class ArtistArt:
             w = width
             h = height
         filename = self.get_artist_cache_name(artist)
-        cache_path_jpg = "%s/%s_%s_%s.jpg" % (self._CACHE_PATH, filename, w, h)
+        cache_path_jpg = "%s/%s_%s_%s.jpg" % (CACHE_PATH, filename, w, h)
         pixbuf = None
         try:
             # Look in cache
@@ -128,8 +131,9 @@ class ArtistArt:
                     try:
                         pixbuf = GdkPixbuf.Pixbuf.new_from_file(path)
                     except:
-                        pass  # Empty file
-                if pixbuf is None:
+                        return None
+                else:
+                    self.cache_artist_artwork(artist)
                     return None
                 pixbuf = self.load_behaviour(pixbuf, cache_path_jpg,
                                              width, height, behaviour)
@@ -143,8 +147,7 @@ class ArtistArt:
             Get a uniq string for artist
             @param artist as str
         """
-        name = "@ARTIST@_%s" % (escape(artist)[:100])
-        return name
+        return md5(artist.encode("utf-8")).hexdigest()
 
     def uncache_artist_artwork(self, artist):
         """
@@ -154,7 +157,7 @@ class ArtistArt:
         try:
             from pathlib import Path
             search = "%s*.jpg" % self.get_artist_cache_name(artist)
-            for p in Path(self._CACHE_PATH).glob(search):
+            for p in Path(CACHE_PATH).glob(search):
                 p.unlink()
         except Exception as e:
             Logger.error("ArtistArt::uncache_artist_artwork(): %s" % e)
