@@ -14,7 +14,8 @@ from gi.repository import GObject, Gio, GLib, GdkPixbuf
 
 from PIL import Image, ImageFilter
 
-from lollypop.define import ArtSize, App, TAG_EDITORS, ArtBehaviour
+from lollypop.define import ArtSize, App, ArtBehaviour
+from lollypop.define import STORE_PATH
 from lollypop.logger import Logger
 
 
@@ -22,11 +23,6 @@ class BaseArt(GObject.GObject):
     """
         Base art manager
     """
-    _CACHE_PATH = GLib.get_user_cache_dir() + "/lollypop"
-    # Fallback when album dir is readonly
-    _STORE_PATH = GLib.get_user_data_dir() + "/lollypop/store"
-    # Store for Web
-    _WEB_PATH = GLib.get_user_data_dir() + "/lollypop/web_store"
     __gsignals__ = {
         "album-artwork-changed": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "artist-artwork-changed": (GObject.SignalFlags.RUN_FIRST,
@@ -41,10 +37,6 @@ class BaseArt(GObject.GObject):
             Init base art
         """
         GObject.GObject.__init__(self)
-        self.__kid3_available = False
-        self.__tag_editor = App().settings.get_value("tag-editor").get_string()
-        self.__kid3_cli_search()
-        self.__tag_editor_search()
 
     def load_behaviour(self, pixbuf, cache_path, width, height, behaviour):
         """
@@ -57,10 +49,8 @@ class BaseArt(GObject.GObject):
         # Crop image as square
         if behaviour & ArtBehaviour.CROP_SQUARE:
             pixbuf = self._crop_pixbuf_square(pixbuf)
-            pixbuf = pixbuf.scale_simple(width, height,
-                                         GdkPixbuf.InterpType.BILINEAR)
         # Crop image keeping ratio
-        if behaviour & ArtBehaviour.CROP:
+        elif behaviour & ArtBehaviour.CROP:
             pixbuf = self._crop_pixbuf(pixbuf, width, height)
 
         # Handle blur
@@ -79,11 +69,6 @@ class BaseArt(GObject.GObject):
                                          height,
                                          GdkPixbuf.InterpType.NEAREST)
             pixbuf = self._get_blur(pixbuf, 100)
-        elif behaviour & ArtBehaviour.CROP:
-            pixbuf = pixbuf.scale_simple(width,
-                                         height,
-                                         GdkPixbuf.InterpType.HYPER)
-            pass
         else:
             pixbuf = pixbuf.scale_simple(width,
                                          height,
@@ -103,48 +88,32 @@ class BaseArt(GObject.GObject):
         """
         value = App().settings.get_value("cover-size").get_int32()
         # Check value as user can enter bad value via dconf
-        if value < ArtSize.SMALL or value > ArtSize.MAX:
+        if value < 170 or value > 300:
             value = 200
         ArtSize.BIG = value
         ArtSize.BANNER = int(ArtSize.BIG * 150 / 200)
-        ArtSize.ARTIST_SMALL = int(ArtSize.BIG * 60 / 200)
+        ArtSize.MEDIUM = int(ArtSize.BIG * 100 / 200)
+        ArtSize.SMALL = int(ArtSize.BIG * 50 / 200)
 
     def clean_store(self, filename):
         """
             @param filename as str
         """
         try:
-            filepath = self._STORE_PATH + "/" + filename + ".jpg"
+            filepath = STORE_PATH + "/" + filename + ".jpg"
             f = Gio.File.new_for_path(filepath)
             if f.query_exists():
                 f.delete()
         except Exception as e:
             Logger.error("Art::clean_store(): %s" % e)
 
-    @property
-    def kid3_available(self):
-        """
-            True if kid3 is available
-            @return bool
-        """
-        return self.__kid3_available
-
-    @property
-    def tag_editor(self):
-        """
-            Get tag editor
-            @return bool
-        """
-        return self.__tag_editor
-
-#######################
-# PROTECTED           #
-#######################
-    def _save_pixbuf_from_data(self, path, data):
+    def save_pixbuf_from_data(self, path, data, width=-1, height=-1):
         """
             Save a pixbuf at path from data
             @param path as str
             @param data as bytes
+            @param width as int
+            @param height as int
         """
         # Create an empty file
         if data is None:
@@ -157,11 +126,18 @@ class BaseArt(GObject.GObject):
             bytes = GLib.Bytes(data)
             stream = Gio.MemoryInputStream.new_from_bytes(bytes)
             pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
+            if width != -1 and height != -1:
+                pixbuf = pixbuf.scale_simple(width,
+                                             height,
+                                             GdkPixbuf.InterpType.BILINEAR)
             stream.close()
             pixbuf.savev(path, "jpeg", ["quality"],
                          [str(App().settings.get_value(
                              "cover-quality").get_int32())])
 
+#######################
+# PROTECTED           #
+#######################
     def _crop_pixbuf(self, pixbuf, wanted_width, wanted_height):
         """
             Crop pixbuf
@@ -248,79 +224,3 @@ class BaseArt(GObject.GObject):
 #######################
 # PRIVATE             #
 #######################
-    def __tag_editor_search(self, editors=TAG_EDITORS):
-        """
-            Search for tag editor
-        """
-        # Search for available tag editors
-        if not self.__tag_editor and editors:
-            editor = editors.pop(0)
-            if GLib.find_program_in_path("flatpak-spawn") is not None:
-                argv = ["flatpak-spawn", "--host",
-                        "sh", "-c", 'command -v %s' % editor]
-            elif GLib.find_program_in_path(editor) is not None:
-                self.__tag_editor = editor
-                return
-            try:
-                (pid, stdin, stdout, stderr) = GLib.spawn_async(
-                    argv, flags=GLib.SpawnFlags.SEARCH_PATH |
-                    GLib.SpawnFlags.STDOUT_TO_DEV_NULL |
-                    GLib.SpawnFlags.DO_NOT_REAP_CHILD,
-                    standard_input=False,
-                    standard_output=False,
-                    standard_error=False
-                )
-                GLib.child_watch_add(GLib.PRIORITY_DEFAULT_IDLE, pid,
-                                     self.__on_tag_editor_result,
-                                     editor, editors)
-            except:
-                self.__on_tag_editor_result(None, 1, editor, editors)
-
-    def __kid3_cli_search(self):
-        """
-            Search for kid3-cli
-        """
-        if GLib.find_program_in_path("flatpak-spawn") is not None:
-            argv = ["flatpak-spawn", "--host",
-                    "sh", "-c", 'command -v kid3-cli']
-        elif GLib.find_program_in_path("kid3-cli") is not None:
-            self.__kid3_available = True
-            return
-        try:
-            (pid, stdin, stdout, stderr) = GLib.spawn_async(
-                argv, flags=GLib.SpawnFlags.SEARCH_PATH |
-                GLib.SpawnFlags.STDOUT_TO_DEV_NULL |
-                GLib.SpawnFlags.DO_NOT_REAP_CHILD,
-                standard_input=False,
-                standard_output=False,
-                standard_error=False
-            )
-            GLib.child_watch_add(GLib.PRIORITY_DEFAULT_IDLE, pid,
-                                 self.__on_kid3_result)
-        except:
-            self.__on_kid3_result(None, 1)
-
-    def __on_tag_editor_result(self, pid, status, editor, editors):
-        """
-            Set editor
-            @param pid as int
-            @param status as bool
-            @param editor as str
-            @param editors as [str]
-        """
-        if pid is not None:
-            GLib.spawn_close_pid(pid)
-        if status == 0:
-            self.__tag_editor = editor
-        else:
-            self.__tag_editor_search(editors)
-
-    def __on_kid3_result(self, pid, status):
-        """
-            Set state
-            @param pid as int
-            @param status as bool
-        """
-        if pid is not None:
-            GLib.spawn_close_pid(pid)
-        self.__kid3_available = status == 0
