@@ -11,6 +11,7 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from lollypop.define import App
+from lollypop.helper_signals import SignalsHelper, signals_map
 
 
 class ViewControllerType:
@@ -18,29 +19,24 @@ class ViewControllerType:
     ALBUM = "album"
 
 
-class ViewController:
+class ViewController(SignalsHelper):
     """
         Update view for registered signals
         Should be herited by a Gtk.Widget
     """
 
+    @signals_map
     def __init__(self, controller_type):
         """
             Init controller
             @param controller_type as ViewControllerType
         """
-        self.__signals_ids = {}
-        self.__type = controller_type
-        self.connect("destroy", self.__on_destroy)
-        self.__signals_ids[
-            App().player.connect("current-changed",
-                                 self._on_current_changed)] = App().player
-        self.__signals_ids[
-            App().player.connect("duration-changed",
-                                 self._on_duration_changed)] = App().player
-        self.__signals_ids[
-            App().art.connect("%s-artwork-changed" % self.__type,
-                              self._on_artwork_changed)] = App().art
+        return [
+            (App().player, "current-changed", "_on_current_changed"),
+            (App().player, "duration-changed", "_on_duration_changed"),
+            (App().art, "%s-artwork-changed" % controller_type,
+             "_on_artwork_changed")
+        ]
 
 #######################
 # PROTECTED           #
@@ -57,11 +53,3 @@ class ViewController:
 #######################
 # PRIVATE             #
 #######################
-    def __on_destroy(self, widget):
-        """
-            Disconnect signals
-            @param widget as Gtk.Widget
-        """
-        for signal_id in self.__signals_ids.keys():
-            self.__signals_ids[signal_id].disconnect(signal_id)
-        self.__signals_ids = {}
