@@ -14,35 +14,36 @@ from gi.repository import GLib, Gio
 
 import sqlite3
 from threading import Lock
+from random import shuffle
 import itertools
 
-from lollypop.define import App
+from lollypop.define import App, StorageType
 from lollypop.database_upgrade import DatabaseAlbumsUpgrade
 from lollypop.sqlcursor import SqlCursor
 from lollypop.logger import Logger
 from lollypop.localized import LocalizedCollation
-from lollypop.utils import noaccents
+from lollypop.utils import noaccents, sql_escape
 
 
 class MyLock:
     """
-        Lock with count
+        Lock with status
     """
     def __init__(self):
         self.__lock = Lock()
-        self.__count = 0
+        self.__locked = False
 
     def acquire(self):
-        self.__count += 1
+        self.__locked = True
         self.__lock.acquire()
 
     def release(self):
-        self.__count -= 1
+        self.__locked = False
         self.__lock.release()
 
     @property
-    def count(self):
-        return self.__count
+    def locked(self):
+        return self.__locked
 
 
 class Database:
@@ -68,6 +69,7 @@ class Database:
                                               rate INT NOT NULL,
                                               loved INT NOT NULL,
                                               mtime INT NOT NULL,
+                                              storage_type INT NOT NULL,
                                               synced INT NOT NULL)"""
     __create_artists = """CREATE TABLE artists (id INTEGER PRIMARY KEY,
                                                name TEXT NOT NULL,
@@ -81,6 +83,10 @@ class Database:
     __create_album_genres = """CREATE TABLE album_genres (
                                                 album_id INT NOT NULL,
                                                 genre_id INT NOT NULL)"""
+    __create_album_timed_popularity = """CREATE TABLE albums_timed_popularity (
+                                                album_id INT NOT NULL,
+                                                mtime INT NOT NULL,
+                                                popularity INT NOT NULL)"""
     __create_tracks = """CREATE TABLE tracks (id INTEGER PRIMARY KEY,
                                               name TEXT NOT NULL,
                                               uri TEXT NOT NULL,
@@ -96,6 +102,7 @@ class Database:
                                               rate INT NOT NULL,
                                               ltime INT NOT NULL,
                                               mtime INT NOT NULL,
+                                              storage_type INT NOT NULL,
                                               mb_track_id TEXT,
                                               bpm DOUBLE
                                               )"""
@@ -133,6 +140,7 @@ class Database:
                     sql.execute(self.__create_genres)
                     sql.execute(self.__create_album_genres)
                     sql.execute(self.__create_album_artists)
+                    sql.execute(self.__create_album_timed_popularity)
                     sql.execute(self.__create_tracks)
                     sql.execute(self.__create_track_artists)
                     sql.execute(self.__create_track_genres)
@@ -152,18 +160,36 @@ class Database:
             @param request as str
             @return list
         """
+        requests = []
         try:
+            union_random = request.find("ORDER BY random()") != -1 and\
+                request.find("UNION") != -1
+            # Special case for UNION, does not support random()
+            # Optimisation, split request and add LIMIT
+            if union_random:
+                request = request.replace("ORDER BY random()", "")
+                limit_position = request.find("LIMIT")
+                limit_str = request[limit_position:]
+                limit_int = int(limit_str.replace("LIMIT ", ""))
+                # Remove limit from main request
+                request = request.replace(limit_str, "")
+                request_split = request.split("UNION")
+                sublimit = limit_int // len(request_split)
+                for request in request_split:
+                    request += " ORDER BY random() LIMIT %s" % sublimit
+                    requests.append(request)
+            else:
+                requests = [request]
+            ids = []
             with SqlCursor(App().db) as sql:
-                result = sql.execute(request)
-                # Special case for OR request
-                if request.find("ORDER BY random()") == -1 and\
-                        request.find("UNION") != -1:
-                    ids = []
-                    for (id, other) in list(result):
-                        ids.append(id)
-                    return ids
+                for request in requests:
+                    result = sql.execute(request)
+                    ids += list(itertools.chain(*result))
+                if union_random:
+                    shuffle(ids)
+                    return ids[:limit_int]
                 else:
-                    return list(itertools.chain(*result))
+                    return ids
         except Exception as e:
             Logger.error("Database::execute(): %s -> %s", e, request)
         return []
@@ -176,6 +202,7 @@ class Database:
             c = sqlite3.connect(self.DB_PATH, 600.0)
             c.create_collation("LOCALIZED", LocalizedCollation())
             c.create_function("noaccents", 1, noaccents)
+            c.create_function("sql_escape", 1, sql_escape)
             return c
         except:
             exit(-1)
@@ -190,28 +217,38 @@ class Database:
         except Exception as e:
             Logger.error("Database::drop_db():", e)
 
-    def exists_in_db(self, album, artists, track):
+    def exists_in_db(self, album, artists, track,
+                     storage_type=StorageType.NONE):
         """
             Search if item exists in db
-            @param track as str
             @param album as str
             @param artists as [str]
-            @return object
+            @param track as str/None
+            @param storage_type as int
+            @return bool
         """
         artist_ids = []
         for artist in artists:
-            artist_id = App().artists.get_id(artist)
+            artist_id = App().artists.get_id_for_escaped_string(
+                sql_escape(artist.lower()))
             artist_ids.append(artist_id)
-        album_id = App().albums.get_id_by_name_artists(album, artist_ids)
+        album_id = App().albums.get_id_by(
+            sql_escape(album.lower()), artist_ids)
         if album_id is None:
-            return None
-        elif App().albums.get_mtime(album_id) > 0 or track is None:
-            return album_id
+            return False
+        album_storage_type = App().albums.get_storage_type(album_id)
+        # If not same storage type, say True!
+        # Don't want to mix StorageType.COLLECTION with some web tracks
+        if track is None:
+            return True
+        elif album_storage_type & StorageType.COLLECTION and\
+                album_storage_type != storage_type:
+            return True
         else:
-            track_id = App().tracks.get_id_by(track,
+            track_id = App().tracks.get_id_by(sql_escape(track.lower()),
                                               album_id,
                                               artist_ids)
-            return track_id
+            return track_id is not None
 
 #######################
 # PRIVATE             #
