@@ -1072,20 +1072,19 @@ class AlbumsDatabase:
                                  (album_id,))
             return list(itertools.chain(*result))
 
-    def get_never_listened_to(self):
+    def get_little_played(self):
         """
-            Return random albums never listened to
+            Return random albums little played
             @return album ids as [int]
         """
         with SqlCursor(App().db) as sql:
             storage_type = get_default_storage_type()
-            result = sql.execute("SELECT DISTINCT albums.rowid\
-                                  FROM albums, tracks\
-                                  WHERE albums.loved != -1 AND\
-                                  albums.storage_type & ? AND\
-                                  albums.rowid=tracks.album_id\
-                                  AND albums.popularity = 0\
-                                  ORDER BY random() LIMIT 100",
+            result = sql.execute("SELECT album_id\
+                                  FROM tracks\
+                                  WHERE storage_type & ?\
+                                  GROUP BY album_id\
+                                  ORDER BY SUM(ltime)/COUNT(ltime), \
+                                  random() LIMIT 100",
                                  (storage_type,))
             return list(itertools.chain(*result))
 
