@@ -10,7 +10,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from lollypop.objects import Track
+from lollypop.objects_track import Track
+from lollypop.utils import emit_signal
 
 
 class QueuePlayer:
@@ -44,7 +45,7 @@ class QueuePlayer:
         self.set_next()
         self.set_prev()
         if notify:
-            self.emit("queue-changed")
+            emit_signal(self, "queue-changed")
 
     def insert_in_queue(self, track_id, pos=0, notify=True):
         """
@@ -60,7 +61,7 @@ class QueuePlayer:
         self.set_next()
         self.set_prev()
         if notify:
-            self.emit("queue-changed")
+            emit_signal(self, "queue-changed")
 
     def remove_from_queue(self, track_id, notify=True):
         """
@@ -71,7 +72,7 @@ class QueuePlayer:
         if track_id in self.__queue:
             self.__queue.remove(track_id)
         if notify:
-            self.emit("queue-changed")
+            emit_signal(self, "queue-changed")
 
     def clear_queue(self, notify=True):
         """
@@ -81,7 +82,7 @@ class QueuePlayer:
         """
         self.__queue = []
         if notify:
-            self.emit("queue-changed")
+            emit_signal(self, "queue-changed")
 
     def track_in_queue(self, track):
         """
