@@ -16,11 +16,14 @@ from time import sleep
 from re import match
 from random import shuffle
 import json
+import os
+import tempfile
 
 from lollypop.logger import Logger
-from lollypop.utils import escape
+from lollypop.utils import escape, emit_signal
 from lollypop.define import App, Type
-from lollypop.objects import Track, Album
+from lollypop.objects_track import Track
+from lollypop.objects_album import Album
 
 
 class MtpSyncDb:
@@ -274,22 +277,22 @@ class MtpSync(GObject.Object):
                         break
                     self.__copy_file(src_uri, dst_uri)
                     self.__done += 1
-                    GLib.idle_add(self.emit, "sync-progress",
-                                  self.__done / self.__total)
+                    emit_signal(self, "sync-progress",
+                                self.__done / self.__total)
                 except Exception as e:
                     Logger.error("MtpSync::__copy_files(): %s", e)
             Logger.debug("Writing playlists")
             if not self.__cancellable.is_cancelled():
                 self.__write_playlists(playlist_ids)
-            GLib.idle_add(self.emit, "sync-progress",
-                          self.__done / self.__total + 1)
+            emit_signal(self, "sync-progress",
+                        self.__done / self.__total + 1)
             Logger.debug("Creating unsync")
             if not self.__cancellable.is_cancelled():
                 d = Gio.File.new_for_uri(self.__uri + "/unsync")
                 if not d.query_exists():
                     d.make_directory_with_parents()
-            GLib.idle_add(self.emit, "sync-progress",
-                          self.__done / self.__total + 2)
+            emit_signal(self, "sync-progress",
+                        self.__done / self.__total + 2)
         except Exception as e:
             Logger.error("MtpSync::__sync(): %s" % e)
         finally:
@@ -299,9 +302,9 @@ class MtpSync(GObject.Object):
             self.cancel()
             if self.__errors_count != 0:
                 Logger.debug("Sync errors")
-                GLib.idle_add(self.emit, "sync-errors", self.__last_error)
+                emit_signal(self, "sync-errors", self.__last_error)
             Logger.debug("Sync finished")
-            GLib.idle_add(self.emit, "sync-finished")
+            emit_signal(self, "sync-finished")
 
     def cancel(self):
         """
@@ -320,7 +323,7 @@ class MtpSync(GObject.Object):
 ############
 # PRIVATE  #
 ############
-    def __get_album_on_device_uri(self, track):
+    def __get_album_name(self, track):
         """
             Get on device URI for album
             @param track as Track
@@ -345,8 +348,7 @@ class MtpSync(GObject.Object):
         for track in tracks:
             f = Gio.File.new_for_uri(track.uri)
             album_device_uri = "%s/%s" % (self.__uri,
-                                          self.__get_album_on_device_uri(
-                                            track))
+                                          self.__get_album_name(track))
             album_local_uri = f.get_parent().get_uri()
             src_uri = "%s/%s" % (album_local_uri,
                                  GLib.uri_escape_string(f.get_basename(),
@@ -373,36 +375,45 @@ class MtpSync(GObject.Object):
             if self.__cancellable.is_cancelled():
                 break
             try:
-                name = escape(App().playlists.get_name(playlist_id))
-                dst_uri = "%s/%s.m3u" % (self.__uri, name)
+                # Get tracks
                 if App().playlists.get_smart(playlist_id):
                     request = App().playlists.get_smart_sql(playlist_id)
                     track_ids = App().db.execute(request)
                 else:
                     track_ids = App().playlists.get_track_ids(playlist_id)
-                # Create playlist
-                m3u = Gio.File.new_for_path("/tmp/lollypop_%s.m3u" % name)
-                content = "#EXTM3U\n"
+
+                # Build tracklist
+                tracklist = "#EXTM3U\n"
                 for track_id in track_ids:
-                    track = Track(track_id)
                     if self.__cancellable.is_cancelled():
                         break
+                    track = Track(track_id)
                     f = Gio.File.new_for_uri(track.uri)
                     filename = f.get_basename()
-                    album_uri = self.__get_album_on_device_uri(track)
+                    print(filename, escape(filename))
+                    album_uri = self.__get_album_name(track)
                     uri = "%s/%s" % (album_uri, escape(filename))
                     (convertion_needed,
                      uri) = self.__is_convertion_needed(track.uri, uri)
-                    content += "%s\n" % uri
-                    m3u.replace_contents(
-                                    content.encode("utf-8"),
+                    tracklist += "%s\n" % uri
+
+                # Write playlist file
+                playlist_name = escape(App().playlists.get_name(playlist_id))
+                playlist_uri = "%s/%s.m3u" % (self.__uri, playlist_name)
+                Logger.debug("MtpSync::__write_playlists(): %s" % playlist_uri)
+                temp_uri = os.path.join(
+                    tempfile.gettempdir(),
+                    "lollypop_%s.m3u" % playlist_name
+                )
+                m3u_temp = Gio.File.new_for_path(temp_uri)
+                m3u_temp.replace_contents(
+                                    tracklist.encode("utf-8"),
                                     None,
                                     False,
                                     Gio.FileCreateFlags.REPLACE_DESTINATION,
                                     self.__cancellable)
-                    dst = Gio.File.new_for_uri(dst_uri)
-                    Logger.debug("MtpSync::__write_playlists(): %s" % dst_uri)
-                    m3u.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
+                m3u = Gio.File.new_for_uri(playlist_uri)
+                m3u_temp.move(m3u, Gio.FileCopyFlags.OVERWRITE, None, None)
             except Exception as e:
                 Logger.error("MtpSync::__write_playlists(): %s", e)
 
