@@ -17,14 +17,13 @@ from random import shuffle
 
 from lollypop.view_flowbox import FlowBoxView
 from lollypop.widgets_album_simple import AlbumSimpleWidget
-from lollypop.define import App, Type, ViewType, MARGIN
+from lollypop.define import App, Type, ViewType, MARGIN, ScanUpdate
 from lollypop.objects_album import Album
 from lollypop.utils import get_icon_name, get_network_available
 from lollypop.utils import get_font_height, get_youtube_dl
 from lollypop.helper_horizontal_scrolling import HorizontalScrollingHelper
 from lollypop.controller_view import ViewController, ViewControllerType
 from lollypop.helper_signals import SignalsHelper, signals_map
-from lollypop.widgets_banner_albums import AlbumsBannerWidget
 
 
 class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
@@ -42,7 +41,6 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
         """
         FlowBoxView.__init__(self, view_type)
         ViewController.__init__(self, ViewControllerType.ALBUM)
-        self._widget_class = AlbumSimpleWidget
         self._genre_ids = genre_ids
         self._artist_ids = artist_ids
         self.__populate_wanted = True
@@ -66,7 +64,7 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
                     self.__populate_wanted = False
             self._empty_icon_name = get_icon_name(genre_ids[0])
         return [
-                (App().scanner, "album-updated", "_on_album_updated")
+            (App().scanner, "album-updated", "_on_album_updated")
         ]
 
     def populate(self):
@@ -116,14 +114,19 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
 #######################
 # PROTECTED           #
 #######################
-    def _add_items(self, albums):
+    def _get_child(self, value):
         """
-            Add albums to the view
-            Start lazy loading
-            @param albums as [Album]
+            Get a child for view
+            @param value as object
+            @return row as SelectionListRow
         """
-        FlowBoxView._add_items(self, albums, self._genre_ids, self._artist_ids,
-                               self._view_type)
+        if self.destroyed:
+            return None
+        widget = AlbumSimpleWidget(value,  self._genre_ids, self._artist_ids,
+                                   self._view_type, self.font_height)
+        self._box.insert(widget, -1)
+        widget.show()
+        return widget
 
     def _get_menu_widget(self, child):
         """
@@ -136,27 +139,27 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
         menu = AlbumMenu(child.data, self._view_type, App().window.is_adaptive)
         return MenuBuilder(menu)
 
-    def _on_album_updated(self, scanner, album_id, added):
+    def _on_album_updated(self, scanner, album_id, scan_update):
         """
             Handles changes in collection
             @param scanner as CollectionScanner
             @param album_id as int
-            @param added as bool
+            @param scan_update as ScanUpdate
         """
-        if added and (not self._genre_ids or
-                      self._genre_ids[0] >= 0 or
-                      self._genre_ids[0] == Type.ALL):
+        if scan_update == ScanUpdate.REMOVED:
+            for child in self.children:
+                if child.data.id == album_id:
+                    child.destroy()
+                    break
+
+        if scan_update == ScanUpdate.ADDED and\
+                self._genre_ids[0] != Type.NONE:  # AlbumsLineView
             album_ids = App().window.container.get_view_album_ids(
                                             self._genre_ids,
                                             self._artist_ids)
             if album_id in album_ids:
                 index = album_ids.index(album_id)
                 self.insert_album(Album(album_id), index)
-        else:
-            for child in self.children:
-                if child.data.id == album_id:
-                    child.destroy()
-                    break
 
     def _on_artwork_changed(self, artwork, album_id):
         """
@@ -222,6 +225,7 @@ class AlbumsGenresBoxView(AlbumsBoxView):
                                view_type |
                                ViewType.OVERLAY |
                                ViewType.SCROLLED)
+        from lollypop.widgets_banner_albums import AlbumsBannerWidget
         self.__banner = AlbumsBannerWidget(genre_ids, artist_ids, view_type)
         self.__banner.show()
         self.__banner.connect("play-all", self.__on_banner_play_all)
@@ -337,8 +341,8 @@ class AlbumsLineView(AlbumsBoxView, HorizontalScrollingHelper):
         self._forward_button = Gtk.Button.new_from_icon_name(
                                                        "go-next-symbolic",
                                                        Gtk.IconSize.BUTTON)
-        self._backward_button.get_style_context().add_class("menu-button-48")
-        self._forward_button.get_style_context().add_class("menu-button-48")
+        self._backward_button.get_style_context().add_class("menu-button")
+        self._forward_button.get_style_context().add_class("menu-button")
         header = Gtk.Grid()
         header.set_column_spacing(10)
         header.add(self._label)
