@@ -15,7 +15,7 @@ from gi.repository import Gtk, GLib
 from gettext import gettext as _
 from time import time
 
-from lollypop.objects import Track
+from lollypop.objects_track import Track
 from lollypop.define import App, Type
 from lollypop.logger import Logger
 
@@ -34,24 +34,31 @@ class RatingWidget(Gtk.Bin):
         """
         Gtk.Bin.__init__(self)
         self.__object = object
-        self.set_property("valign", Gtk.Align.CENTER)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/RatingWidget.ui")
         builder.connect_signals(self)
-
+        self.__empty_star = builder.get_object("empty_star")
         self._stars = []
         for i in range(0, 5):
             star = builder.get_object("star%s" % i)
             star.set_from_icon_name("starred-symbolic", icon_size)
             self._stars.append(star)
-        builder.get_object("empty_star").set_from_icon_name("starred-symbolic",
-                                                            icon_size)
+        self.__empty_star.set_from_icon_name("starred-symbolic", icon_size)
         self._on_leave_notify_event(None, None)
         self.add(builder.get_object("widget"))
         if isinstance(object, Track):
             play_count = object.popularity
             self.set_tooltip_text(_("Song played %s times") % play_count)
 
+    def set_icon_size(self, icon_size):
+        """
+            Set widget icon size
+            @param icon_size as Gtk.IconSize
+        """
+        for start in self._stars:
+            start.set_from_icon_name("starred-symbolic", icon_size)
+        self.__empty_star.set_from_icon_name("starred-symbolic", icon_size)
+
 #######################
 # PROTECTED           #
 #######################
@@ -162,33 +169,37 @@ class RatingWidget(Gtk.Bin):
             Set popularity as kid3 is installed
             @param pop as int
         """
-        try:
-            if App().art.kid3_available:
-                if pop == 0:
-                    value = 0
-                elif pop == 1:
-                    value = 1
-                elif pop == 2:
-                    value = 64
-                elif pop == 3:
-                    value = 128
-                elif pop == 4:
-                    value = 196
-                else:
-                    value = 255
-                path = GLib.filename_from_uri(self.__object.uri)[0]
-                if GLib.find_program_in_path("flatpak-spawn") is not None:
-                    argv = ["flatpak-spawn", "--host", "kid3-cli", "-c",
-                            "set POPM %s" % value, path]
-                else:
-                    argv = ["kid3-cli", "-c", "set POPM %s" % value, path]
-                if App().scanner.inotify is not None:
-                    App().scanner.inotify.disable()
+        if pop == 0:
+            value = 0
+        elif pop == 1:
+            value = 1
+        elif pop == 2:
+            value = 64
+        elif pop == 3:
+            value = 128
+        elif pop == 4:
+            value = 196
+        else:
+            value = 255
+        path = GLib.filename_from_uri(self.__object.uri)[0]
+        arguments = [["kid3-cli", "-c", "set POPM %s" % value, path],
+                     ["flatpak-spawn", "--host", "kid3-cli", "-c",
+                      "set POPM %s" % value, path]]
+        if App().scanner.inotify is not None:
+            App().scanner.inotify.disable()
+        worked = False
+        for argv in arguments:
+            try:
                 (pid, stdin, stdout, stderr) = GLib.spawn_async(
                     argv, flags=GLib.SpawnFlags.SEARCH_PATH |
                     GLib.SpawnFlags.STDOUT_TO_DEV_NULL
                 )
                 # Force mtime update to not run a collection update
                 App().tracks.set_mtime(self.__object.id, int(time()) + 10)
-        except Exception as e:
-            Logger.error("RatingWidget::__on_can_set_popularity(): %s" % e)
+                worked = True
+                break
+            except Exception as e:
+                Logger.error("RatingWidget::__on_can_set_popularity(): %s" % e)
+        if not worked:
+            App().notify.send("Lollypop",
+                              _("You need to install kid3-cli"))
