@@ -12,9 +12,7 @@
 
 from gi.repository import Gtk, GLib
 
-from gettext import gettext as _
-
-from lollypop.define import App, NetworkAccessACL
+from lollypop.define import App, NetworkAccessACL, StorageType
 
 
 class BehaviourSettingsWidget(Gtk.Bin):
@@ -57,9 +55,7 @@ class BehaviourSettingsWidget(Gtk.Bin):
         switch_mix_party.set_state(App().settings.get_value("party-mix"))
 
         switch_artwork_tags = builder.get_object("switch_artwork_tags")
-
-        # Check for kid3-cli
-        self.__check_for_kid3(switch_artwork_tags)
+        switch_artwork_tags.set_state(App().settings.get_value("save-to-tags"))
 
         self.__popover_transitions = builder.get_object("popover-transitions")
         self.__scale_transition_duration = builder.get_object(
@@ -110,8 +106,13 @@ class BehaviourSettingsWidget(Gtk.Bin):
             acl &= ~NetworkAccessACL[key]
         acl = App().settings.set_value("network-access-acl",
                                        GLib.Variant("i", acl))
-        App().art.reset_history()
-        App().art.cache_artists_artwork()
+        if key == "SPOTIFY" and not state:
+            for storage_type in [StorageType.SPOTIFY_NEW_RELEASES,
+                                 StorageType.SPOTIFY_SIMILARS]:
+                App().tracks.del_old_for_storage_type(storage_type, 0)
+            App().tracks.clean()
+            App().albums.clean()
+            App().artists.clean()
 
     def _on_switch_scan_state_set(self, widget, state):
         """
@@ -204,18 +205,3 @@ class BehaviourSettingsWidget(Gtk.Bin):
 #######################
 # PRIVATE             #
 #######################
-    def __check_for_kid3(self, switch):
-        """
-            Update grid/switch based on result
-            @param switch as Gtk.Switch
-        """
-        if not App().art.kid3_available:
-            box = switch.get_parent()
-            switch.destroy()
-            label = Gtk.Label.new(_("You need to install kid3-cli"))
-            label.get_style_context().add_class("dim-label")
-            label.set_property("halign", Gtk.Align.END)
-            label.show()
-            box.pack_end(label, False, False, 0)
-        else:
-            switch.set_state(App().settings.get_value("save-to-tags"))
